@@ -1,7 +1,9 @@
 #include <QDir>
 #include <QDebug>
 #include <QRegularExpression>
+
 #include "aptcache.h"
+#include "cmd.h"
 
 AptCache::AptCache()
 {
@@ -35,22 +37,20 @@ void AptCache::loadCacheFiles()
             re_temprepo.match(file_name).hasMatch()) {
             continue;
         }
-        if ( re_binary_arch.match(file_name).hasMatch()) {
+        if (re_binary_arch.match(file_name).hasMatch()) {
             files << file_name;
             continue;
         }
-        if ( not re_binary_other.match(file_name).hasMatch()) {
+        if (not re_binary_other.match(file_name).hasMatch()) {
             files << file_name;
             continue;
         }
     }
 
 
-    for (const QString &file_name : files) {
-        if(!readFile(file_name)) {
+    for (const QString &file_name : files)
+        if(!readFile(file_name))
             qDebug() << "error reading a cache file";
-        }
-    }
     parseContent();
 }
 
@@ -59,9 +59,18 @@ const QMap<QString, QStringList> AptCache::getCandidates()
     return candidates;
 }
 
-QString AptCache::getArch()
+// return DEB_BUILD_ARCH format which differs from what 'arch' returns
+const QString AptCache::getArch()
 {
-    return (system("arch | grep -q x86_64") == 0) ? "amd64" : "i386";
+    Cmd cmd;
+    QString out = cmd.getCmdOut("arch");
+    if (out == "x86_64")
+        return "amd64";
+    if (out == "i686")
+        return "i386";
+    if (out == "armv7l")
+        return "armhf";
+    return QString();
 }
 
 void AptCache::parseContent()
@@ -92,9 +101,8 @@ void AptCache::parseContent()
             version = line.remove(QLatin1String("Version: "));
         } else if (line.startsWith(QLatin1String("Description:"))) { // not "Description: " because some people don't add description to their packages
             description = line.remove(QLatin1String("Description:")).trimmed();
-            if (match_arch) {
+            if (match_arch)
                 add_package = true;
-            }
         }
         // add only packages with correct architecure
         if (add_package and match_arch) {
@@ -119,7 +127,7 @@ void AptCache::parseContent()
 bool AptCache::readFile(const QString &file_name)
 {
     QFile file(dir_name + file_name);
-    if(!file.open(QFile::ReadOnly)) {
+    if(not file.open(QFile::ReadOnly)) {
         qDebug() << "Could not open file: " << file.fileName();
         return false;
     }
